setwd("C:/Users/Gidon Frischkorn/Documents/Publications/Manuscripts/JoI - ModerationWPA/Revision_1.0/Supplement")
#Read data from supplementary datafiles
data_S1 <- read.table("WPA_S1_data.txt", header = TRUE, sep = "\t")
data_S3 <- read.table("WPA_S3_data.txt", header = TRUE, sep = "\t")
data_S5 <- read.table("WPA_S5_data.txt", header = TRUE, sep = "\t")

data_S1 <- subset(data_S1, ZMeanSet2 != is.na(data_S1$ZMeanSet2))
data_S3 <- subset(data_S3, ZMeanSet2 != is.na(data_S1$ZMeanSet2))
data_S5 <- subset(data_S5, ZMeanSet2 != is.na(data_S1$ZMeanSet2))

X <- 9 #define number of percentiles
Y <- 5 #define percentile to be centered to

#Estimate MLM for Sternberg condition S5
#Define and compute percentile variables
data_S5$perc <- as.numeric(data_S5$perc)
data_S5$perc.center <- data_S5$perc - Y
data_S5$PercQuad <- data_S5$perc.center^2
data_S5$PercThree <- data_S5$perc.center^3

library(nlme)
#models for data_S5
#Baseline-Model: Random intercept, no slope model
mod0 <- lme(RT_mean ~ 1, random = ~1|Subject, data = data_S5,
            method ="ML", na.action = na.omit, 
            control = lmeControl(opt = "optim"))

#Random Intercept - Fixed Slope: p
mod1 <- lme(RT_mean ~ perc.center,
            random = ~1|Subject, data = data_S5, method ="ML", na.action = na.omit,
            control = lmeControl(opt = "optim"))

#Random Intercept - Fixed Slope: p, p^2
mod2 <- lme(RT_mean ~ perc.center + PercQuad,
            random = ~1|Subject, data = data_S5, method ="ML", na.action = na.omit,
            control = lmeControl(opt = "optim"))

#Random Intercept - Fixed Slope: p, p^2, p^3
mod3 <- lme(RT_mean ~ perc.center + PercQuad + PercThree,
            random = ~1|Subject, data = data_S5, method ="ML", na.action = na.omit,
            control = lmeControl(opt = "optim"))

#Random Intercept - Fixed Slope: p, p^2, p^3 - Random Slope: p
mod4 <- lme(RT_mean ~ perc.center + PercQuad + PercThree,
            random = ~1 + perc.center|Subject, data = data_S5, method ="ML", na.action = na.omit,
            control = lmeControl(opt = "optim"))

#Random Intercept - Fixed Slope: p, p^2, p^3 - Random Slope: p, p^2
mod5 <- lme(RT_mean ~ perc.center + PercQuad + PercThree,
            random = ~1 + perc.center + PercQuad |Subject, data = data_S5, method ="ML", na.action = na.omit,
            control = lmeControl(opt = "optim"))

#Random Intercept - Fixed Slope: p, p^2, p^3 - Random Slope: p, p^2, p^3
mod6 <- lme(RT_mean ~ perc.center + PercQuad + PercThree,
            random = ~1 + perc.center + PercQuad + PercThree |Subject, data = data_S5, method ="ML", na.action = na.omit,
            control = lmeControl(opt = "optim"))

#Random Intercept - Fixed Slope: p, p^2, p^3, g - Random Slope: p, p^2, p^3
mod7 <- lme(RT_mean ~ perc.center + PercQuad + PercThree + ZMeanSet2,
            random = ~1 + perc.center + PercQuad + PercThree |Subject, data = data_S5, method ="ML", na.action = na.omit,
            control = lmeControl(opt = "optim"))

#Random Intercept - Fixed Slope: p, p^2, p^3, g, p:g - Random Slope: p, p^2, p^3
mod8 <- lme(RT_mean ~ perc.center + PercQuad + PercThree + ZMeanSet2 
            + perc.center:ZMeanSet2,
            random = ~1 + perc.center + PercQuad + PercThree |Subject, data = data_S5, method ="ML", na.action = na.omit,
            control = lmeControl(opt = "optim"))

#Random Intercept - Fixed Slope: p, p^2, p^3, g, p:g, p^2:g - Random Slope: p, p^2, p^3
mod9 <- lme(RT_mean ~ perc.center + PercQuad + PercThree + ZMeanSet2 
            + perc.center:ZMeanSet2 + PercQuad:ZMeanSet2,
            random = ~1 + perc.center + PercQuad + PercThree |Subject, data = data_S5, method ="ML", na.action = na.omit,
            control = lmeControl(opt = "optim")) #increase Iterations

#Random Intercept - Fixed Slope: p, p^2, p^3, g, p:g, p^2:g, p^3:g - Random Slope: p, p^2, p^3
mod10 <- lme(RT_mean ~ perc.center + PercQuad + PercThree + ZMeanSet2 
             + perc.center:ZMeanSet2 + PercQuad:ZMeanSet2 + PercThree:ZMeanSet2,
             random = ~1 + perc.center + PercQuad + PercThree  |Subject,
             data = data_S5, method ="ML", na.action = na.omit,
             control = lmeControl(opt = "optim"))

#Sequential Model comparison for the estimated models
Fit_S5 <- anova(mod0, mod1, mod2, mod3, mod4, mod5, mod6, mod7, mod8, mod9, mod10)
Fit_S5
Comparison_S5 <- anova(mod7,mod9, mod10) #Comparison for non-sequential models
Comparison_S5
mod_c3_accepted <- mod10 #definde the retained model
rm(mod0, mod1, mod2, mod3, mod4, mod5, mod6, mod7, mod8, mod9, mod10) # remove estimated models

### Model estimation for the S3 and S1 condition is equal ###

#Estimate MLM for Sternberg condition3
data_S3$perc <- as.numeric(data_S3$perc)
data_S3$perc.center <- data_S3$perc - Y
data_S3$PercQuad <- data_S3$perc.center^2
data_S3$PercThree <- data_S3$perc.center^3

library(nlme)
#models for data S3
mod0 <- lme(RT_mean ~ 1, random = ~1|Subject, data = data_S3,
            method ="ML", na.action = na.omit, 
            control = lmeControl(opt = "optim"))

mod1 <- lme(RT_mean ~ perc.center,
            random = ~1|Subject, data = data_S3, method ="ML", na.action = na.omit,
            control = lmeControl(opt = "optim"))

mod2 <- lme(RT_mean ~ perc.center + PercQuad,
            random = ~1|Subject, data = data_S3, method ="ML", na.action = na.omit,
            control = lmeControl(opt = "optim"))

mod3 <- lme(RT_mean ~ perc.center + PercQuad + PercThree,
            random = ~1|Subject, data = data_S3, method ="ML", na.action = na.omit,
            control = lmeControl(opt = "optim"))

mod4 <- lme(RT_mean ~ perc.center + PercQuad + PercThree,
            random = ~1 + perc.center|Subject, data = data_S3, method ="ML", na.action = na.omit,
            control = lmeControl(opt = "optim"))

mod5 <- lme(RT_mean ~ perc.center + PercQuad + PercThree,
            random = ~1 + perc.center + PercQuad |Subject, data = data_S3, method ="ML", na.action = na.omit,
            control = lmeControl(opt = "optim"))

mod6 <- lme(RT_mean ~ perc.center + PercQuad + PercThree,
            random = ~1 + perc.center + PercQuad + PercThree |Subject, data = data_S3, method ="ML", na.action = na.omit,
            control = lmeControl(opt = "optim"))

mod7 <- lme(RT_mean ~ perc.center + PercQuad + PercThree + ZMeanSet2,
            random = ~1 + perc.center + PercQuad + PercThree |Subject, data = data_S3, method ="ML", na.action = na.omit,
            control = lmeControl(opt = "optim"))

mod8 <- lme(RT_mean ~ perc.center + PercQuad + PercThree + ZMeanSet2 
            + perc.center:ZMeanSet2,
            random = ~1 + perc.center + PercQuad + PercThree |Subject, data = data_S3, method ="ML", na.action = na.omit,
            control = lmeControl(opt = "optim"))

mod9 <- lme(RT_mean ~ perc.center + PercQuad + PercThree + ZMeanSet2 
            + perc.center:ZMeanSet2 + PercQuad:ZMeanSet2,
            random = ~1 + perc.center + PercQuad + PercThree |Subject, data = data_S3, method ="ML", na.action = na.omit,
            control = lmeControl(opt = "optim")) #increase Iterations

mod10 <- lme(RT_mean ~ perc.center + PercQuad + PercThree + ZMeanSet2 
             + perc.center:ZMeanSet2 + PercQuad:ZMeanSet2 + PercThree:ZMeanSet2,
             random = ~1 + perc.center + PercQuad + PercThree  |Subject,
             data = data_S3, method ="ML", na.action = na.omit,
             control = lmeControl(opt = "optim"))

Fit_S3 <- anova(mod0, mod1, mod2, mod3, mod4, mod5, mod6, mod7, mod8, mod9, mod10)
Fit_S3
Comparison_S3 <- anova(mod7, mod10)
Comparison_S3
mod_c2_accepted <- mod10
rm(mod0, mod1, mod2, mod3, mod4, mod5, mod6, mod7, mod8, mod9, mod10)

#Estimate MLM for Sternberg condition3
data_S1$perc <- as.numeric(data_S1$perc)
data_S1$perc.center <- data_S1$perc - Y
data_S1$PercQuad <- data_S1$perc.center^2
data_S1$PercThree <- data_S1$perc.center^3

library(nlme)
#models for data_S1
mod0 <- lme(RT_mean ~ 1, random = ~1|Subject, data = data_S1,
            method ="ML", na.action = na.omit, 
            control = lmeControl(opt = "optim"))

mod1 <- lme(RT_mean ~ perc.center,
            random = ~1|Subject, data = data_S1, method ="ML", na.action = na.omit,
            control = lmeControl(opt = "optim"))

mod2 <- lme(RT_mean ~ perc.center + PercQuad,
            random = ~1|Subject, data = data_S1, method ="ML", na.action = na.omit,
            control = lmeControl(opt = "optim"))

mod3 <- lme(RT_mean ~ perc.center + PercQuad + PercThree,
            random = ~1|Subject, data = data_S1, method ="ML", na.action = na.omit,
            control = lmeControl(opt = "optim"))

mod4 <- lme(RT_mean ~ perc.center + PercQuad + PercThree,
            random = ~1 + perc.center|Subject, data = data_S1, method ="ML", na.action = na.omit,
            control = lmeControl(opt = "optim"))

mod5 <- lme(RT_mean ~ perc.center + PercQuad + PercThree,
            random = ~1 + perc.center + PercQuad |Subject, data = data_S1, method ="ML", na.action = na.omit,
            control = lmeControl(opt = "optim"))

mod6 <- lme(RT_mean ~ perc.center + PercQuad + PercThree,
            random = ~1 + perc.center + PercQuad + PercThree |Subject, data = data_S1, method ="ML", na.action = na.omit,
            control = lmeControl(opt = "optim"))

mod7 <- lme(RT_mean ~ perc.center + PercQuad + PercThree + ZMeanSet2,
            random = ~1 + perc.center + PercQuad + PercThree |Subject, data = data_S1, method ="ML", na.action = na.omit,
            control = lmeControl(opt = "optim"))

mod8 <- lme(RT_mean ~ perc.center + PercQuad + PercThree + ZMeanSet2 
            + perc.center:ZMeanSet2,
            random = ~1 + perc.center + PercQuad + PercThree |Subject, data = data_S1, method ="ML", na.action = na.omit,
            control = lmeControl(opt = "optim"))

mod9 <- lme(RT_mean ~ perc.center + PercQuad + PercThree + ZMeanSet2 
            + perc.center:ZMeanSet2 + PercQuad:ZMeanSet2,
            random = ~1 + perc.center + PercQuad + PercThree |Subject, data = data_S1, method ="ML", na.action = na.omit,
            control = lmeControl(opt = "optim")) #increase Iterations

mod10 <- lme(RT_mean ~ perc.center + PercQuad + PercThree + ZMeanSet2 
             + perc.center:ZMeanSet2 + PercQuad:ZMeanSet2 + PercThree:ZMeanSet2,
             random = ~1 + perc.center + PercQuad + PercThree  |Subject,
             data = data_S1, method ="ML", na.action = na.omit,
             control = lmeControl(opt = "optim"))

Fit_S1 <- anova(mod0, mod1, mod2, mod3, mod4, mod5, mod6, mod7, mod8, mod9, mod10)
Fit_S1
Comparison_S1 <- anova(mod6, mod10)
Comparison_S1
mod_c1_accepted <- mod10
rm(mod0, mod1, mod2, mod3, mod4, mod5, mod6, mod7, mod8, mod9, mod10)

#Output of the MLM approach for the retained models
summary(mod_c1_accepted) #for S1 condition
summary(mod_c2_accepted) #for S3 condition
summary(mod_c3_accepted) #for S5 condition
