#read Datasets
data_S1 <- read.table("WPA_S1_data.txt", header = TRUE, sep = "\t")
data_S3 <- read.table("WPA_S3_data.txt", header = TRUE, sep = "\t")
data_S5 <- read.table("WPA_S5_data.txt", header = TRUE, sep = "\t")

data_RT1 <- data_S1[c("Subject","perc" , "RT_mean")]
data_RT3 <- data_S3[c("Subject","perc" , "RT_mean")]
data_RT5 <- data_S5[c("Subject","perc" , "RT_mean")]

library(reshape2)
data_RT1 <- dcast(data_RT1, Subject ~ perc)
data_RT3 <- dcast(data_RT3, Subject ~ perc)
data_RT5 <- dcast(data_RT5, Subject ~ perc)

cor(data_RT1$`1`, data_RT1$`9`)
cor(data_RT3$`1`, data_RT3$`9`)
cor(data_RT5$`1`, data_RT5$`9`)

X <- 9 #define number of percentiles
Y <- 5 #define percentile to be centered to

### Sequential Regression Analysis for memory Set Size 1 ###

perc <- c(1:X)
Coeff_cond1  <- as.data.frame(matrix(rep(NA,10),1,10)) #DataFrame for estimated coefficients
colnames(Coeff_cond1) <- c("Intercept", "dum$Z_gMean", "Corr", "SD_RT", "SD_IQ",
                           "SE_Int", "SE_b", "R square", "p Value", "F Value")
Coeff_cond1 <- Coeff_cond1[-1,]

#Step 1: Predicting RT in each percentile by g
#Loop for estimating Regression in each percentile - Step 1
for(p in perc){
  dum <- subset(data_S1, perc == p)   #Select a subset of one percentile p
  age <- lm(dum$RT_mean ~ dum$age)
  Reg <- lm(age$residuals ~ dum$Z_gMean) #Regression from RT on G in the percentile p
  #Save estimated coefficients of the regression
  Rsquare <- summary(Reg)$r.squared
  pVal <- anova(Reg)$'Pr(>F)'[1]
  Fval <- summary(Reg)$fstatistic[1]
  Corr <- cor(dum$RT_mean, dum$Z_gMean)
  SD_RT  <- sd(dum$RT_mean)
  SD_IQ  <- sd(dum$Z_gMean)
  SE_Int <- summary(Reg)$coefficients[1,2]
  SE_b <- summary(Reg)$coefficients[2,2]
  #Merge estimated parameters into one data frame
  dim <- cbind(Reg$coefficients[1], Reg$coefficients[2], Corr, SD_RT, SD_IQ,
               SE_Int, SE_b, Rsquare, pVal, Fval)
  colnames(dim) <- c("Inter", "b", "Corr", "SD_RT", "SD_IQ", 
                     "SE_Int", "SE_b", "R square", "p Value", "F Value")
  dim <- as.vector(dim)
  Coeff_cond1  <- rbind(Coeff_cond1, dim)
}
#rename variables in Coefficient table
colnames(Coeff_cond1)  <- c("Inter", "b", "Corr", "SD_RT", "SD_IQ", 
                            "SE_Int", "SE_b", "R square", "p Value", "F Value")

#Step 2: Predicting the unstandardized regression weights by percentile
percentile  <- rep(1:X) #define percentile variable
Coeff_cond1 <- cbind(Coeff_cond1, percentile) #merge percentile variable into dataframe
rm(Corr, dim, p, perc, percentile, pVal, Reg, Rsquare, SD_IQ, SD_RT) #remove unneccessary values

#Center and calculate percentile variables
Coeff_cond1$percentile <- Coeff_cond1$percentile-Y
Coeff_cond1$percentile2 <- Coeff_cond1$percentile^2
Coeff_cond1$percentile3 <- Coeff_cond1$percentile^3

#Predicting the relationship between RT and g across percentiles 
#with percentile variables
WPR_cond1 <- lm(Coeff_cond1$b ~ Coeff_cond1$percentile + Coeff_cond1$percentile2 +  Coeff_cond1$percentile3)
summary(WPR_cond1) #Output for the sequential regression analysis

### Sequential Regression Analysis for memory Set Size 3 ###

perc <- c(1:X)
Coeff_cond2  <- as.data.frame(matrix(rep(NA,8),1,8))
colnames(Coeff_cond2) <- c("Intercept", "dum$Z_gMean", "Corr", "SD_RT", "SD_IQ", "R square", "p Value", "F Value")
Coeff_cond2 <- Coeff_cond2[-1,]

#Loop for estimating Regression in each percentile - Step 1
for(p in perc){
  dum <- subset(data_S3, perc == p)   #Select a subset of one percentile p
  age <- lm(dum$RT_mean ~ dum$age)
  Reg <- lm(age$residuals ~ dum$Z_gMean) #Regression from RT on G in the percentile p
  #Estimated parameters for the regression in percentile p
  Rsquare <- summary(Reg)$r.squared
  pVal <- anova(Reg)$'Pr(>F)'[1]
  Fval <- summary(Reg)$fstatistic[1]
  Corr <- cor(dum$RT_mean, dum$Z_gMean)
  SD_RT  <- sd(dum$RT_mean)
  SD_IQ  <- sd(dum$Z_gMean)
  #Merge estimated parameters into one data frame
  dim <- cbind(Reg$coefficients[1], Reg$coefficients[2], Corr, SD_RT, SD_IQ, Rsquare, pVal, Fval)
  colnames(dim) <- c("Intercept", "dum$Z_gMean", "Corr", "SD_RT", "SD_IQ", "R square", "p Value", "F Value")
  dim <- as.vector(dim)
  Coeff_cond2  <- rbind(Coeff_cond2, dim)
}
#rename variables in Coefficient table
colnames(Coeff_cond2)  <- c("Inter", "b", "Corr", "SD_RT", "SD_IQ", "R square", "p Value", "F Value")

#Step 2: Predicting the unstandardized regression weights by percentile
percentile  <- rep(1:X)
Coeff_cond2 <- cbind(Coeff_cond2, percentile)
rm(Corr, dim, p, perc, percentile, pVal, Reg, Rsquare, SD_IQ, SD_RT)

#Center and calculate percentile variables
Coeff_cond2$percentile <- Coeff_cond2$percentile-Y
Coeff_cond2$percentile2 <- Coeff_cond2$percentile^2
Coeff_cond2$percentile3 <- Coeff_cond2$percentile^3

#Predicting the relationship between RT and g across percentiles 
#with percentile variables
WPR_cond2 <- lm(Coeff_cond2$b ~ Coeff_cond2$percentile + Coeff_cond2$percentile2 +  Coeff_cond2$percentile3)
summary(WPR_cond2)

### Sequential Regression Analysis for memory Set Size 5 ###
perc <- c(1:X)
p <- 1
Coeff_cond3  <- as.data.frame(matrix(rep(NA,8),1,8))
colnames(Coeff_cond3) <- c("Intercept", "dum$Z_gMean", "Corr", "SD_RT", "SD_IQ", "R square", "p Value", "F Value")
Coeff_cond3 <- Coeff_cond3[-1,]

for(p in perc){
  dum <- subset(data_S5, perc == p)
  age <- lm(dum$RT_mean ~ dum$age)
  Reg <- lm(age$residuals ~ dum$Z_gMean)
  Rsquare <- summary(Reg)$r.squared
  Fval <- summary(Reg)$fstatistic[1]
  pVal <- anova(Reg)$'Pr(>F)'[1]
  Corr <- cor(dum$RT_mean, dum$Z_gMean)
  SD_RT  <- sd(dum$RT_mean)
  SD_IQ  <- sd(dum$Z_gMean)
  dim <- cbind(Reg$coefficients[1], Reg$coefficients[2], Corr, SD_RT, SD_IQ, Rsquare, pVal, Fval)
  colnames(dim) <- c("Intercept", "dum$Z_gMean", "Corr", "SD_RT", "SD_IQ", "R square", "p Value", "F Value")
  dim <- as.vector(dim)
  Coeff_cond3  <- rbind(Coeff_cond3, dim)
}
colnames(Coeff_cond3)  <- c("Inter", "b", "Corr", "SD_RT", "SD_IQ", "R square", "p Value", "F Value")
percentile  <- rep(1:X)
Coeff_cond3 <- cbind(Coeff_cond3, percentile)
rm(Corr, dum, dim, p, perc, percentile, pVal, Reg, Rsquare, SD_IQ, SD_RT)

Coeff_cond3$percentile <- Coeff_cond3$percentile-Y
Coeff_cond3$percentile2 <- Coeff_cond3$percentile^2
Coeff_cond3$percentile3 <- Coeff_cond3$percentile^3

WPR_cond3 <- lm(Coeff_cond3$b ~ Coeff_cond3$percentile + Coeff_cond3$percentile2 +  Coeff_cond3$percentile3)
summary(WPR_cond3)

#Compute effect size given in Definition 3 for the parameter estimated 
#by the regression
compES_reg <- function(Int,P,P2,P3,NPerc, mu){
  Min = -(NPerc-1)/2
  Max = (NPerc-1)/2
  b_BP = Int + P*Min + P2*Min^2 + P3*Min^3
  b_WP = Int + P*Max + P2*Max^2 + P3*Max^3
  ES = abs((b_WP - b_BP))/mu
  names(ES) <- "effect size"
  return(ES)
}
ES1 <- compES_reg(Int=WPR_cond1$coefficients[1],P=WPR_cond1$coefficients[2],
                  P2 = WPR_cond1$coefficients[3],P3=WPR_cond1$coefficients[4],NPerc=X, mu = 587.9)
ES2 <- compES_reg(Int=WPR_cond2$coefficients[1],P=WPR_cond2$coefficients[2],
                  P2 = WPR_cond2$coefficients[3],P3=WPR_cond2$coefficients[4],NPerc=X, mu = 726.7)
ES3 <- compES_reg(Int=WPR_cond3$coefficients[1],P=WPR_cond3$coefficients[2],
                  P2 = WPR_cond3$coefficients[3],P3=WPR_cond3$coefficients[4],NPerc=X, mu = 889.6)

#Output of the effect sizes for the three conditions
ES1
ES2
ES3

#for the coefficients of each regression for each percentile
#see the Coefficient tables
View(Coeff_cond1)
View(Coeff_cond2)
View(Coeff_cond3)


par(mar=c(5,5,3,2)) 
#Plot estimated unstandardized regression weights (from step 2) 
#against actual regression weights (from step 1)
P <- c(1:X)
Est_S1 = WPR_cond1$coefficients[1]+WPR_cond1$coefficients[2]*(P-Y) + WPR_cond1$coefficients[3]*((P-Y)^2) + WPR_cond1$coefficients[4]*((P-Y)^3)
Est_S3 = WPR_cond2$coefficients[1]+WPR_cond2$coefficients[2]*(P-Y) + WPR_cond2$coefficients[3]*((P-Y)^2) + WPR_cond2$coefficients[4]*((P-Y)^3)
Est_S5 = WPR_cond3$coefficients[1]+WPR_cond3$coefficients[2]*(P-Y) + WPR_cond3$coefficients[3]*((P-Y)^2) + WPR_cond3$coefficients[4]*((P-Y)^3)


plot(c(1:X),c(rep(0,X)),type="l", 
     xlab="percentile", ylab="unstand. regression weight of RT on IQ",
     xlim=c(1,X), ylim=rev(c(-250,0)), xaxt="n",
     main="", cex.lab=1.7, cex.axis=1.7, cex.main=1.7, cex.sub=1.7)
axis(1,at=c(1:X), cex.axis =1.5) #X-Achsen aufteilung
lines(c(1:X),c(rep(-50,X)), type="l")
lines(c(1:X),c(rep(-100,X)), type="l")
lines(c(1:X),c(rep(-150,X)), type="l")
lines(c(1:X),c(rep(-200,X)), type="l")
lines(c(1:X),c(rep(-250,X)), type="l")
lines(Coeff_cond1[,2], type="p", pch=19, lwd=3, col="gray60")
lines(Est_S1, type = "l", lwd=3, lty=1, col="gray60")
lines(Coeff_cond2[,2], type="p", pch=19, lwd=3, col="gray30")
lines(Est_S3, type = "l", lwd=3, lty=2, col="gray30")
lines(Coeff_cond3[,2], type="p", pch=19, lwd=3, col="gray0")
lines(Est_S5, type = "l", lwd=3, lty=3, col="gray0")
legend("topleft", inset = .10, c("S1 est", "S3 est", "S5 est", "S1", "S3", "S5"), ncol = 2, cex = 1.5,
       lty=c(1,2,3,NA,NA,NA), pch=c(NA,NA,NA,20,20,20), lwd = 3, col=c("gray60", "gray30", "gray0"))

cor(Coeff_cond1$b, Coeff_cond1$percentile, method = "spearman")
cor(Coeff_cond2$b, Coeff_cond2$percentile, method = "spearman")
cor(Coeff_cond3$b, Coeff_cond3$percentile, method = "spearman")

#Sequential approach with correlation as DV in Step2
cor(Coeff_cond1$Corr, Coeff_cond1$percentile, method = "spearman")
cor(Coeff_cond2$Corr, Coeff_cond2$percentile, method = "spearman")
cor(Coeff_cond3$Corr, Coeff_cond3$percentile, method = "spearman")

WPRr_cond1 <- lm(Coeff_cond1$Corr ~ Coeff_cond1$percentile)
WPRr_cond2 <- lm(Coeff_cond2$Corr ~ Coeff_cond2$percentile)
WPRr_cond3 <- lm(Coeff_cond3$Corr ~ Coeff_cond3$percentile)

summary(WPRr_cond1)
summary(WPRr_cond2)
summary(WPRr_cond3)

#Plot estimated correlations against actual correlations
P <- c(1:X)
#compute estimated regression weights across percentiles
EstR_S1 = WPRr_cond1$coefficients[1]+WPRr_cond1$coefficients[2]*(P-Y)
EstR_S3 = WPRr_cond2$coefficients[1]+WPRr_cond2$coefficients[2]*(P-Y)
EstR_S5 = WPRr_cond3$coefficients[1]+WPRr_cond3$coefficients[2]*(P-Y)

plot(c(1:X),c(rep(0,X)),type="l", 
     xlab="percentile", ylab="r(IQ,RT)",
     xlim=c(1,X), ylim=rev(c(-0.6,-0.1)), xaxt="n",
     main="", cex.lab=1.5, cex.axis=1.5, cex.main=1.5, cex.sub=1.5)
     axis(1,at=c(1:X), cex.axis =1.5) #X-Achsen aufteilung
#draw horizontal lines
lines(c(1:X),c(rep(-0.1,X)), type="l")
lines(c(1:X),c(rep(-0.2,X)), type="l")
lines(c(1:X),c(rep(-0.3,X)), type="l")
lines(c(1:X),c(rep(-0.4,X)), type="l")
lines(c(1:X),c(rep(-0.5,X)), type="l")
lines(c(1:X),c(rep(-0.6,X)), type="l")
#draw dots and lines for coefficients and estimated coefficients
lines(Coeff_cond1[,3], type="p", pch=4, lwd=3, col="coral3")
  lines(EstR_S1, type = "l", lwd=3, col="coral3")
lines(Coeff_cond2[,3], type="p", pch=4, lwd=3, col="darkolivegreen4")
  lines(EstR_S3, type = "l", lwd=3, col="darkolivegreen4")
lines(Coeff_cond3[,3], type="p", pch=4, lwd=3, col="cornflowerblue")
  lines(EstR_S5, type = "l", lwd=3, col="cornflowerblue")
#insert legend
legend("topleft", inset = .05, c("S1 est", "S3 est", "S5 est", "S1", "S3", "S5"), ncol = 2, cex = 1.5,
       lty=c(1,1,1,NA,NA,NA), pch=c(NA,NA,NA,4,4,4), lwd = 3, col=c("coral3", "darkolivegreen4", "cornflowerblue"))
